==> igniteui-webcomponents-core-4.0.2.tgz: package/esm5/lib/WebGridClipboardOptionsDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import * as tslib_1 from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebGridClipboardOptionsDescription } from "./WebGridClipboardOptionsDescription";
/**
 * @hidden
 */
var WebGridClipboardOptionsDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    tslib_1.__extends(WebGridClipboardOptionsDescriptionMetadata, _super);
    function WebGridClipboardOptionsDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    WebGridClipboardOptionsDescriptionMetadata.b = function (a) {
        if (WebGridClipboardOptionsDescriptionMetadata.a == null) {
            WebGridClipboardOptionsDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            WebGridClipboardOptionsDescriptionMetadata.c(WebGridClipboardOptionsDescriptionMetadata.a);
        }
        if (a.j(WebGridClipboardOptionsDescriptionMetadata.a)) {
            return;
        }
        a.y(WebGridClipboardOptionsDescriptionMetadata.a);
    };
    WebGridClipboardOptionsDescriptionMetadata.c = function (a) {
        a.item("__qualifiedNameTS", "String:GridClipboardOptions");
    };
    WebGridClipboardOptionsDescriptionMetadata.d = function (a) {
        WebGridClipboardOptionsDescriptionMetadata.b(a);
        a.aa("WebGridClipboardOptions", function () { return new WebGridClipboardOptionsDescription(); });
        a.z("WebGridClipboardOptions", WebGridClipboardOptionsDescriptionMetadata.a);
    };
    WebGridClipboardOptionsDescriptionMetadata.$t = markType(WebGridClipboardOptionsDescriptionMetadata, 'WebGridClipboardOptionsDescriptionMetadata');
    WebGridClipboardOptionsDescriptionMetadata.a = null;
    return WebGridClipboardOptionsDescriptionMetadata;
}(Base));
export { WebGridClipboardOptionsDescriptionMetadata };

==> igniteui-webcomponents-core-4.2.5.tgz: package/esm5/lib/WebGridClipboardOptionsDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import * as tslib_1 from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebGridClipboardOptionsDescription } from "./WebGridClipboardOptionsDescription";
/**
 * @hidden
 */
var WebGridClipboardOptionsDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    tslib_1.__extends(WebGridClipboardOptionsDescriptionMetadata, _super);
    function WebGridClipboardOptionsDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    WebGridClipboardOptionsDescriptionMetadata.b = function (a) {
        if (WebGridClipboardOptionsDescriptionMetadata.a == null) {
            WebGridClipboardOptionsDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            WebGridClipboardOptionsDescriptionMetadata.c(WebGridClipboardOptionsDescriptionMetadata.a);
        }
        if (a.k(WebGridClipboardOptionsDescriptionMetadata.a)) {
            return;
        }
        a.aa(WebGridClipboardOptionsDescriptionMetadata.a);
    };
    WebGridClipboardOptionsDescriptionMetadata.c = function (a) {
        a.item("__qualifiedNameTS", "String:GridClipboardOptions");
    };
    WebGridClipboardOptionsDescriptionMetadata.d = function (a) {
        WebGridClipboardOptionsDescriptionMetadata.b(a);
        a.ac("WebGridClipboardOptions", function () { return new WebGridClipboardOptionsDescription(); });
        a.ab("WebGridClipboardOptions", WebGridClipboardOptionsDescriptionMetadata.a);
    };
    WebGridClipboardOptionsDescriptionMetadata.$t = markType(WebGridClipboardOptionsDescriptionMetadata, 'WebGridClipboardOptionsDescriptionMetadata');
    WebGridClipboardOptionsDescriptionMetadata.a = null;
    return WebGridClipboardOptionsDescriptionMetadata;
}(Base));
export { WebGridClipboardOptionsDescriptionMetadata };
